/* See LICENSE file for copyright and license details. */
#include <X11/XF86keysym.h>

/* appearance */
static const unsigned int borderpx  = 1;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "JetBrainsMono Nerd Font Mono:size=11" };
static const char dmenufont[]       = "JetBrainsMono Nerd Font Mono:size=11";

/* Pywal16 */ 
#include "/home/philip/.cache/wal/colors-wal-dwm.h"

/* tagging */
static const char *tags[] = { "Ⅰ" ,"Ⅱ", "Ⅲ", "Ⅳ"}; //, "5", "6", "7", "8", "9" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class        instance    title       tags mask     isfloating   monitor */
	{ "ghostty",    NULL,       NULL,       1 << 0,       0,           -1 },
	{ "librewolf",  NULL,       NULL,       1 << 1,       0,           -1 },
	{ "Chromium",   NULL,       NULL,       1 << 1,       0,           -1 },
	{ "Gimp",       NULL,       NULL,       1 << 2,       1,           -1 },
	{ "gThumb",     NULL,       NULL,       1 << 2,       1,           -1 },
	{ "Galculator", NULL,       NULL,       1 << 8,       1,           -1 },
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "Ƭ",      tile },    /* first entry is default */
	{ "Φ",      NULL },    /* no layout function means floating behavior */
	{ "µ",      monocle }, /* everything is maximised */
};

/* key definitions */
/* modifiers are ShiftMask, LockMask, ControlMask, Mod1Mask, Mod2Mask, Mod3Mask, Mod4Mask and Mod5Mask */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { "dmenu_run", "-m", dmenumon, "-fn", dmenufont, "-nb", norm_bg, "-nf", norm_fg, "-sb", sel_bg, "-sf", sel_fg, NULL };
static const char *termcmd[]   = { "ghostty", NULL };
static const char *wwwcmd[]    = { "librewolf", NULL };
static const char *brighter[]  = { "brightnessctl", "set", "10%+", NULL };
static const char *dimmer[]    = { "brightnessctl", "set", "10%-", NULL };
static const char *bluetooth[] = { "blueman-manager", NULL };
static const char *scrotcmd[]  = { "screenshot.sh", NULL};

static const Key keys[] = {
	/* modifier                     key        function        argument */
    { 0,            XF86XK_AudioMute,          spawn,          SHCMD("~/.local/bin/dwm-audio voltoggle") },
    { 0,            XF86XK_AudioLowerVolume,   spawn,          SHCMD("~/.local/bin/dwm-audio volquieter") },
    { 0,            XF86XK_AudioRaiseVolume,   spawn,          SHCMD("~/.local/bin/dwm-audio vollouder") },
    { 0,            XF86XK_AudioMicMute,       spawn,          SHCMD("~/.local/bin/dwm-audio mictoggle") },
	{ 0,            XF86XK_MonBrightnessDown,  spawn,          {.v = dimmer   } },
	{ 0,            XF86XK_MonBrightnessUp,    spawn,          {.v = brighter } },
	{ 0,            XF86XK_Launch1,            spawn,          SHCMD("rofi -show power-menu -modi power-menu:rofi-power-menu") },
	{ 0,                            XK_Menu,   spawn,          SHCMD("rofi -show power-menu -modi power-menu:rofi-power-menu") },
	{ 0,                            XK_Print,  spawn,          {.v = scrotcmd } },
	{ MODKEY,                       XK_b,      togglebar,      {0} },
	{ MODKEY,                       XK_d,      incnmaster,     {.i = -1 } },
	{ MODKEY,                       XK_f,      setlayout,      {.v = &layouts[1]} },
	{ MODKEY,                       XK_h,      setmfact,       {.f = -0.05} },
	{ MODKEY,                       XK_i,      incnmaster,     {.i = +1 } },
	{ MODKEY,                       XK_l,      setmfact,       {.f = +0.05} },
	{ MODKEY,                       XK_m,      setlayout,      {.v = &layouts[2]} },
	{ MODKEY,                       XK_r,      spawn,          SHCMD("rofi -show run") },
	{ MODKEY,                       XK_p,      spawn,          {.v = dmenucmd } },
	{ MODKEY,                       XK_t,      setlayout,      {.v = &layouts[0]} },
	{ MODKEY,                       XK_w,      spawn,          {.v = wwwcmd   } },
	{ MODKEY,                       XK_Return, spawn,          {.v = termcmd  } },
	{ MODKEY,                       XK_Right,  focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_Left,   focusstack,     {.i = -1 } },
	{ MODKEY,                       XK_Tab,    view,           {0} },
	{ MODKEY,                       XK_space,  setlayout,      {0} },
	{ MODKEY,                       XK_agrave, view,           {.ui = ~0 } },
	{ MODKEY,                       XK_comma,  focusmon,       {.i = -1 } },
	{ MODKEY,                       XK_semicolon, focusmon,    {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_b, spawn,               {.v = bluetooth } },
	{ MODKEY|ShiftMask,             XK_c,      killclient,     {0} },
	{ MODKEY|ShiftMask,             XK_Right,  view_adjacent,  {.i = +1 } },
    { MODKEY|ShiftMask,             XK_Left,   view_adjacent,  {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_Return, zoom,           {0} },
	{ MODKEY|ShiftMask,             XK_space,  togglefloating, {0} },
	{ MODKEY|ShiftMask,             XK_agrave, tag,            {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_semicolon, tagmon,      {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_q,      quit,           {0} },
	{ MODKEY|ShiftMask,             XK_x,      spawn,          SHCMD("rofi -show power-menu -modi power-menu:rofi-power-menu") },
	TAGKEYS(                        XK_ampersand,              0)
	TAGKEYS(                        XK_eacute,                 1)
	TAGKEYS(                        XK_quotedbl,               2)
	TAGKEYS(                        XK_apostrophe,             3)
	TAGKEYS(                        XK_parenleft,              4)
	TAGKEYS(                        XK_minus,                  5)
	TAGKEYS(                        XK_egrave,                 6)
	TAGKEYS(                        XK_underscore,             7)
	TAGKEYS(                        XK_ccedilla,               8)
	TAGKEYS(                        XK_agrave,                 9)
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
	{ ClkTagBar,            0,              Button4,        view_adjacent,  {.i = -1 } },
	{ ClkTagBar,            0,              Button5,        view_adjacent,  {.i = +1 } },
};

